;
;	>>> Silly Things by JAC! <<<
;
;	Created 2010-10-10/2010-12-09 for the Sillyventure 2010 in Gdansk.
;	This is the "Silly Things Header" used by the intro and the main part.

; Constants
pixels_set	= 212
header_sm_size	= 200

; Zero Page
header_map1	= header_zp		;32 bytes, $00, $10, $20, ... $f0, $e0, ...$00
header_map2	= header_map1+$20	;32 bytes, $00, $01, $02, ... $0f, $0e, ...$00


	.proc effect

	.var map_cnt			.byte
	.var map_fade			.byte
	.var fast_mode_pages	:32 	.byte

	.proc init		;Initialize the color map to white, returns Y=0 for subsequent call
	lda #0
	tax
clear_loop
	sta header_sm,x
	inx
	cpx #header_sm_size
	bne clear_loop
	lda #15
	sta map_fade
	ldy #0
	sty map_cnt
	jmp init_maps
	.endp


	.proc init_colors	;Initialize color addresses based on the color map
	ldx #0
	mwa #[routine+routine.routine1+1] store_adr
loop
	lda data.header_map,x
	ora data.header_color,x
	sta $ffff
store_adr = *-2
	lda store_adr
	clc
	adc data.header_adradd+1,x	;Add offset to next LDA/ORA
	sta store_adr
	bcc no_inc
	inc store_adr+1
no_inc	inx
	cpx #pixels_set
	bne loop
	jmp move_fully
	.endp


	.proc init_maps		;Initialize the maps in cylce <Y> with brightness map_fade
	ldx #31
loop	tya
	and #31
	cmp #16
	bcc *+4
	eor #31

	clc
	adc map_fade
	cmp #16
	bcc *+4
	lda #15
	sta header_map2,x
	asl
	asl
	asl
	asl
	sta header_map1,x
	iny
	dex
	bpl loop
	rts
	.endp

	.proc init_fast_mode	;A=page start storing 32 pages 
	.var count	.byte
	sta store_adr+1

	lda #0			;Reset all counter
	sta count
	sta map_cnt
	sta map_fade		;Completely faded down
	tay			;Phase 0
	jsr init_maps
move_loop
	ldy count		;Passe phase counter as argument
	jsr move_fully

	ldx count		;Store page number in page table
	lda store_adr+1
	sta fast_mode_pages,x

	ldx #0			;Copy page content
copy_loop
	lda header_sm,x
	sta $ff00,x
store_adr = *-2
	inx
	cpx #header_sm_size
	bne copy_loop
	inc store_adr+1

	inc count
	lda count
	cmp #32
	bne move_loop
	rts

	.endp

	.proc move_fully	;Performs 6 call to move to ensure one full roundtrip
	jsr move_twice		;Perform 4 calls to ensure the header_sm is filled
	jsr move_twice
move_twice
	jsr move		;Fall trough!
	.endp

	.proc move		;Animate the header in 6 steps, one step per call
	ldx #0
move_cnt = *-1
	beq jmp_routine1
	dex
	beq jmp_routine2
	dex
	beq jmp_routine3
	dex
	beq jmp_routine4
	dex
	beq scroll_map1
	jmp scroll_map2

jmp_routine1
	inc move_cnt
	jmp routine+routine.routine1
jmp_routine2
	inc move_cnt
	jmp routine+routine.routine2
jmp_routine3
	inc move_cnt
	jmp routine+routine.routine3
jmp_routine4
	inc move_cnt
	jmp routine+routine.routine4

scroll_map1
	ldx header_map1+31
	.rept 31
	lda header_map1+30-#
	sta header_map1+31-#
	.endr
	stx header_map1
	inc move_cnt
	rts

scroll_map2
	ldx header_map2+31
	.rept 31
	lda header_map2+30-#
	sta header_map2+31-#
	.endr
	stx header_map2
	inc map_cnt

	mva #0 move_cnt
	rts

	.endp	;End of move

	.proc move_fast_mode		;Animate the header like move but in fase mode
	ldx move.move_cnt		;Returns move_cnt in <X> and page in <A>
	inx
	cpx #6
	bne no_step
	ldx #0
	inc map_cnt
no_step	stx move.move_cnt

	lda map_cnt
	and #31
	tay
	lda fast_mode_pages,y
	rts
	.endp	;End of move_fast_mode

	
	.proc fade_down		;Returns with "negative" if fading is completed
 	lda move.move_cnt
	bne return
	lda map_fade
	bmi return

	ldy map_cnt
	jsr init_maps

	dec map_fade
return	lda map_fade
	rts
	.endp

	.endp	;End of effect
