;
;	>>> Silly Things by JAC! <<<
;
;	Created 2010-10-10/2010-12-09 for the Sillyventure 2010 in Gdansk.
;	This is the "Silly Things Intro Letter Part".

;.def debug_mode

; Constants
max_letters		= 40		;40 byte per row

letter_lines		= 204		;Visible lines
letter_size		= 160		;4*40 bytes
letter_shades		= 8		;Number of shades per letter

phase_not_started	= $ff		;Must be negative
phase_completed		= $fe		;Must be negative
phase_start		= 127		;Must be positive

; Zero page
cmc_player_zp		= intro_zp	;4 bytes
p1			= intro_zp+4	;2 bytes pointer
letter_offset		= intro_zp+6	;1 bytes, currnet y offset
letter_count		= intro_zp+7	;1 bytes, number of letters to display
letter_index		= intro_zp+8	;1 byte, current letter which is about to start
letter_color1		= intro_zp+9	;1 byte, Color mask with mask $0f
letter_color2		= intro_zp+10	;1 byte, Color mask with mask $f0
letter_phase		= intro_zp+11	;max_letters bytes with phase counters

; Main memory
generated_letters	= $5900		;About $1648 bytes
generated_end		= $8200		;Actually $8128

sound_start		= $5000		;Player
sound_d200		= $5800		;Buffer for fading
music_start		= $8400		;CMC module up to $8B18

letter_base		= $9600
letter_dl		= letter_base+$000		;Permanent
letter_llo		= letter_base+$100		;Permanent
letter_lhi		= letter_base+$200		;Permanent
letter_wave1		= letter_base+$300		;Permanent
letter_wave2		= letter_base+$400		;Permanent
letter_adrlo		= letter_base+$500		;Temporary during generation
letter_adrhi		= letter_base+$500+max_letters	;Temporary during generation

letter_sm		= $a010	;2*102 lines of 40 bytes per line, 2*$ff0 = $1fe0 bytes
				;plus $348 bytes overrun area, will be overwritten by the header_sm


	org *	;Origin is specified by including file

;===============================================================
; The kernel stuff is included again here

	icl "Silly-Kernel.asm"	

;===============================================================

	.proc init

	lda vcount			;Disable screen
	bne *-3
	sta sdmctl
	sta dmactl

	lda #$ff			;Disable Basic
	sta portb

	jsr sound.init			;Initialize sound

	jsr effect.init
	jsr effect.clear
 	
 	jsr sync.vcount
 	lda #$22
 	sta dmactl
 	sta sdmctl
 	
 	lda #setvbv.immediate		;Play tune in VBI during generation
 	ldx #>effect.vbi
 	ldy #<effect.vbi
 	jsr setvbv

	.if .def fast_mode
	rts
	.endif

 	lda #0				;Coming Up ...
	ldx #<effect.descriptor1
	ldy #>effect.descriptor1
	jsr effect.init_letters
	jsr effect.move_letters
	
	jsr effect.fade_out

	lda #0
 	ldx #<effect.descriptor2	;Silly Things
	ldy #>effect.descriptor2
	jsr effect.init_letters
	jsr effect.move_letters


	lda #100
 	ldx #<effect.descriptor3	;JAC - 505 - OOZ
	ldy #>effect.descriptor3
	jsr effect.init_letters
	jsr effect.move_letters

	lda #50
	jsr wait

	jsr effect.fade_out
	
wait_cmc2
	lda sound.player.possng
	cmp #5
	bcc wait_cmc2
	lda sound.player.posptr
	cmp #$38
	bcc wait_cmc2

	lda #100
 	ldx #<effect.descriptor4	;Loading
	ldy #>effect.descriptor4
	jsr effect.init_letters
	jsr effect.move_letters

  	rts				;Continue loading
 
;===============================================================

	.proc effect

;===============================================================

letter_shade_color
;	.byte $ff,$dd,$bb,$99,$77,$55,$33,$00	;Graphics 9
	.byte $ff,$66,$55,$44,$33,$22,$11,$00	;Graphics 10

letter_fade_color
	.byte $00,$01,$02,$03,$04,$05,$06,$07	;Graphics 10
	.byte $07,$07,$07,$07,$07,$07,$07,$07

	.proc init			;One-time initialization

lines	= 102				;Lines in one 4k block
lms1	= $02				;Offset in the DL
lms2	= lms1+lines+2			;Offset in the DL
wvbl	= lms2+lines+2

	ldx #lines-1			;Init the DL
loop_dl	lda #$0f
	sta letter_dl+lms1+3,x
	sta letter_dl+lms2+3,x
	dex
	bpl loop_dl

	lda #$70
	sta letter_dl
	sta letter_dl+1

	lda #$4f
	sta letter_dl+lms1
	sta letter_dl+lms2
	mwa #letter_sm letter_dl+lms1+1
	mwa #letter_sm+lines*40 letter_dl+lms2+1

	mva #$41 letter_dl+wvbl
	mwa #letter_dl letter_dl+wvbl+1

	mwa #letter_dl sdlstl

	.if .def debug_mode
	lda #14
	sta color1
	lda #$74
	sta color2
	.else
	lda #$80
	sta gprior
	.endif
	
	mwa #letter_sm p1
	ldx #0
loop_llohi
	mva p1 letter_llo,x
	mva p1+1 letter_lhi,x
	cpx #[letter_lines+1]		;Everything beyond letter_lines is overrun
	bcs no_llohi
	adw p1 #40 
no_llohi
	inx
	bne loop_llohi

	rts
	.endp				;End of init

;===============================================================

	.proc init_letters	;<A>=y offset, <X/Y>=low/high of descriptor
	
	sta letter_offset
	stx generate_letters.letter_count_adr
	sty generate_letters.letter_count_adr+1
	
	jsr generate_letters
	jsr generate_prints
	jsr init_waves
	rts

;===============================================================

	.proc generate_letters

;	Variables
	.var letter		.byte
	.var start_offset	.byte
	.var end_offset		.byte

	lda $ffff
letter_count_adr = *-2
	sta letter_count

	clc
	lda letter_count_adr
	adc #1
	sta letter_color_adr
	lda letter_count_adr+1
	adc #0
	sta letter_color_adr+1

	lda $ffff
letter_color_adr = *-2	
	ldx #0			;Sets the color scheme to <A> = $x0
color_loop
	clc
	adc #2
	sta pcolor1,x
	sta colpm1,x
	inx
	cpx #6
	bne color_loop
	lda #14
	sta pcolor1,x
	sta colpm1,x

	clc
	lda letter_color_adr
	adc #1
	sta start_offsets_adr
	lda letter_color_adr+1
	adc #0
	sta start_offsets_adr+1

	clc
	lda start_offsets_adr
	adc letter_count
	sta end_offsets_adr
	lda start_offsets_adr+1
	adc #0
	sta end_offsets_adr+1
	
	clc
	lda end_offsets_adr
	adc letter_count
	sta generate_letter.get_two_pixels.picture_adr
	lda end_offsets_adr+1
	adc #0
	sta generate_letter.get_two_pixels.picture_adr+1

	adw generate_letter.get_two_pixels.picture_adr #50 move_letters.move.start_phases_adr

	mwa #generated_letters	poke.poke_adr
	mva #0 letter
loop	ldx letter
	mva poke.poke_adr letter_adrlo,x
	mva poke.poke_adr+1 letter_adrhi,x
	lda $ffff,x
start_offsets_adr = *-2
	sta start_offset
	lda $ffff,x
end_offsets_adr = *-2
	sta end_offset
	jsr generate_letter
	inc letter
	lda letter
	cmp letter_count
	bne loop
	rts


;===============================================================

	.proc generate_letter
	.var ycnt		.byte 
	.var xcnt		.byte 
	
	lda #$b9		;lda letter_llo,y
	ldx #<letter_llo
	ldy #>letter_llo
	jsr poke.poke_axy	;sta p1	
	ldx #$85
	ldy #p1
	jsr poke.poke_xy

	lda #$b9		;lda letter_lhi,y
	ldx #<letter_lhi
	ldy #>letter_lhi
	jsr poke.poke_axy	;sta p1+1
	ldx #$85
	ldy #p1+1
	jsr poke.poke_xy

	lda #0
	sta store_two_pixels.last_was_txa
	sta ycnt
loopy	lda start_offset	;byte offset in the target
	sta xcnt
loopx	jsr get_two_pixels
	jsr store_two_pixels

;	lda poke.poke_adr+1	;Safety net
;	cmp #>generated_end
;	bcc *+3
;	jam

	inc xcnt
	lda xcnt
	cmp end_offset
	bne loopx

	inc ycnt
	lda ycnt
	cmp #5
	bcs done

	lda #$18		;clc
	ldx #$a5		;lda p1
	ldy #p1
	jsr poke.poke_axy
	ldx #$69		;adc #letter_size
	ldy #letter_size
	jsr poke.poke_xy
	ldx #$85		;sta p1
	ldy #p1
	jsr poke.poke_xy

	ldx #$90		;bcc *+5
	ldy #2
	jsr poke.poke_xy
	ldx #$e6		;inc p1+1
	ldy #p1+1
	jsr poke.poke_xy

	asl store_two_pixels.last_was_txa
	jmp  loopy

done	jmp poke.poke_rts

;===============================================================

	.proc get_two_pixels
	.var tmp		.byte
	.var pixel		.byte

	lda ycnt
	asl
	sta tmp
	asl
	asl
	clc
	adc tmp
	sta tmp
	
	lda xcnt
	lsr
	lsr
	clc
	adc tmp
	tax

	lda $ffff,x
picture_adr = *-2
	sta pixel

	lda xcnt
	and #3
	eor #3
	tax
	beq no_shift
shift	lsr pixel
	lsr pixel
	dex
	bne shift
no_shift
	lda pixel
	and #3
	sta pixel
	rts
	
	.endp

;===============================================================

	.proc store_two_pixels
	.var andmask		.byte
	.var colreg		.byte
	.var source_offset	.byte
	.var last_was_txa	.byte

	ldy get_two_pixels.pixel
	beq no_bit

	lda andmasks,y
	sta andmask
	lda colregs-1,y
	sta colreg

	lda #0
	sta source_offset
next_line
	jsr same_line
	clc
	lda source_offset
	adc #40
	sta source_offset
	cmp #letter_size
	bne next_line
	rts

same_line
	ldx #$a0		;ldy #0
	clc
	lda xcnt
	adc source_offset
	tay
	jsr poke.poke_xy

	lda andmask		;and/ora required?
	bne poke_lda		;No

	lda last_was_txa
	bne txa_not_required
	lda #$8a		;txa, equals lda colreg but saves 1 cycle
	jsr poke.poke_a
	lda #$80
	sta last_was_txa

txa_not_required
	jmp poke_sta

poke_lda
	asl last_was_txa

	ldx #$b1		;lda (p1),y
	ldy #p1
	jsr poke.poke_xy

	ldx #$29		;and #mask
	ldy andmask
	jsr poke.poke_xy
	ldx #$05		;ora colreg
	ldy colreg
	jsr poke.poke_xy

poke_sta
	ldx #$91		;sta (p1),y
	ldy #p1
	jsr poke.poke_xy
no_bit
	rts

andmasks	.byte $ff,$f0,$0f,$00
colregs		.byte letter_color1,letter_color2

	.endp		;End of store_two_pixels

	.endp		;End of generate_letter

	.endp		;End of generate_letter
;===============================================================
; Continues the generate at the current poke address.
; Here is the original routine.
;	.proc print_letters
;
;	.macro print_letter
;	.echo :1, "-", :2
;	
;	.if :2 = 15
;	ldy letter_wave1+:3,x
;	.else
;	ldy letter_wave2+:3,x
;	.endif
;	cpy #letter_lines
;	bcs *+25
;
;	lda #:2
;	sta letter_color1
;	lda #:2*$10
;	sta letter_color2
;	ldx #:2*$11
;
;	jsr letter_jsr:1
;
;	.if :2 <>15
;	ldx letter_phase+:1
;	.endif
;	.endm
; 
;	.rept letters, #, $0f
;	ldx letter_phase+#
;	jmi next_letter:1
;
;	print_letter #, 0, 7
;	print_letter #, 3, 6
;	print_letter #, 5, 5
;	print_letter #, 7, 4
;	print_letter #, 9, 3
;	print_letter #, 11, 2
;	print_letter #, 13, 1
;	print_letter #, 15, 0
;
;next_letter:1	
;	.endr
;	rts
;
;	.endp
	
	.proc generate_prints
; Variables
	.var letter	.byte
	.var jump_adr	.word

	mwa poke.poke_adr print.generated_prints_adr
	mva #0 letter
loop	
	ldx #$a6		;ldx letter_phase+#; (ZP)
	lda letter
	clc
	adc #<letter_phase
	tay
	jsr poke.poke_xy
	ldx #$10		;bpl *+5
	ldy #$03
	jsr poke.poke_xy
	mwa poke.poke_adr p1	;Remember jump instruction address
	lda #$4c		;jmp ????
	jsr poke.poke_axy

	jsr generate_print
	ldy #1
	lda poke.poke_adr	;Set jump address
	sta (p1),y
	iny
	lda poke.poke_adr+1
	sta (p1),y

	inc letter
	lda letter
	cmp letter_count
	bne loop
	jmp poke.poke_rts


;===============================================================
	
	.proc generate_print
	.var letter_shade	.byte
	mva #letter_shades-1 letter_shade
loop
	ldy #>letter_wave1
	ldx letter_shade	;Index is color 15
	beq *+4
	ldy #>letter_wave2
	lda #$bc		;ldy letter_wave1/2+:3,x
	jsr poke.poke_axy

	ldx #$c0		;cpy #letter_lines
	ldy #letter_lines
	jsr poke.poke_xy

	ldx #$b0		;bcs to next ldy
	ldy #15
	lda letter_shade
	bne *+4
	ldy #13			;there will not be an ldy to skip
	jsr poke.poke_xy

	ldx letter_shade	;lda #:2
	lda letter_shade_color,x
	and #$0f
	tay
	ldx #$a9
	jsr poke.poke_xy
	ldx #$85		;sta letter_color1
	ldy #letter_color1
	jsr poke.poke_xy

	ldx letter_shade	;lda #:2*$10
	lda letter_shade_color,x
	and #$f0
	tay
	ldx #$a9
	jsr poke.poke_xy
	ldx #$85		;sta letter_color2
	ldy #letter_color2
	jsr poke.poke_xy

	ldx letter_shade	;ldx #:2*$11
	ldy letter_shade_color,x
	ldx #$a2
	jsr poke.poke_xy

	lda #$20		;jsr letter0..letters
	jsr poke.poke_a
	ldx letter
	lda letter_adrlo,x
	jsr poke.poke_a
	lda letter_adrhi,x
	jsr poke.poke_a

	ldx letter_shade	;Index is color 15
	beq no_color15

	ldx #$a6		;ldx letter_phase+#; (ZP)
	lda letter
	clc
	adc #<letter_phase
	tay
	jsr poke.poke_xy

no_color15

	dec letter_shade
	jpl loop
	rts

	.endp	;End of generate_print

	.endp	;End of generate_prints

;===============================================================
	.proc init_waves

	ldx #0
loop_waves
	cpx #16
	bcs after_16
	lda wave
	jsr add_offset
	sta letter_wave1,x
	lda #letter_lines		;Switch off drawing
	sta letter_wave2,x		;Below phase 16 for dark letters
after_16
	cpx #128
	bcc before_128
	lda #letter_lines		;Switch off drawing
	sta letter_wave1,x		;Above phase 128
	sta letter_wave2,x		;Above phase 128
before_128
	inx
	bne loop_waves

	lda #letter_lines		;Switch off drawing
	sta letter_wave1		;In phase 0 for the white letter

	ldx #16
loop_waves_copy
	lda wave-16,x
	jsr add_offset
	sta letter_wave1,x
	sta letter_wave2,x
	inx
	bpl loop_waves_copy

 	ldx #max_letters-1
 	lda #phase_not_started
init_phase
 	sta letter_phase,x
 	dex
 	bpl init_phase
 	lda #0
 	sta letter_index
	rts

	.proc add_offset
	cmp #letter_lines
	bcs return
	clc
	adc letter_offset
	bcs overflow
	cmp #letter_lines
	bcc return
overflow
	lda #letter_lines
return	rts
	.endp

;	Generated by "INTRO.TUR"
wave	.byte 0,1,2,4,6,8,10,12,14,17,19,22,24,27,29,32,35,37,40,43,45,48,50,52,55,57,58,60,62,63,64,65,66,66,67,67,66,66,66,65,64,63,61,60,58,56,54,52,50,48,45,43,40,38,36,34,31,29,27,26,24,23,21,20,20,19,19,20,20,21,23,24,26,29,32,35,38,43,47,52,57,62,68,74,81,87,94,102,109,116,124,132,140,148,156,163,171,179,186,194,201,208,214,220,226,232,237,241,245,249,252,255
;	.byte 84,85,86,88,89,91,93,94,96,98,100,102,105,107,109,111,112,114,116,118,119,120,121,122,123,124,124,124,124,123,123,122,120,119,117,115,113,110,107,104,101,97,93,89,85,81,76,72,67,63,58,53,49,44,40,35,31,27,23,19,16,12,10,7,5,3,2,1,0,0,0,1,2,3,6,8,11,15,18,23,28,33,38,44,50,57,63,70,78,85,92,100,108,115,123,131,138,145,153,159,166,172,178,184,189,194,198,202,205,207,209,211
	.endp		;End of init_waves

	.end		;End of init_letters


;===============================================================

	.local descriptor1
	.byte 11					;letter_count
	.byte $00					;letter_color
;	.byte  C  O  M  I  N  G  U  P  .  .  .
	.byte 2, 6,10,14,15,19,25,29,33,35,36		;start_offsets
	.byte 6,10,14,15,19,23,29,33,35,36,38		;end_offsets
	ins "intro/Silly-Intro-Coming-Up.pic"		;picture
	.byte 00,70,50,90,70,50,50,50,110,110,110	;start_phases
	.endl

	.local descriptor2
	.byte 11					;letter_count
	.byte $30					;letter_color
;	.byte  S  I  L  L  Y  T  H  I  N  G  S
	.byte  0, 4, 5, 9,13,18,23,27,28,32,36		;start_offsets
	.byte  4, 5, 9,13,17,23,27,28,32,36,40		;end_offsets
	ins "intro/Silly-Intro-Header.pic"		;picture
	.byte 00,100,80,70,70,80,80,100,60,50,50	;start_phases
	.endl

	.local descriptor3
	.byte 11					;letter_count
	.byte $c0					;letter_color
;	.byte  J  A  C  -  5  0  5  -  O  O  Z
	.byte  0, 4, 8, 12,14,18,22,26,28,32,36		;start_offsets
	.byte  4, 8, 12,14,18,22,26,28,32,36,40		;end_offsets
	ins "intro/Silly-Intro-Authors.pic"		;picture
	.byte 00,80,80,70,80,80,80,70,80,80,80	;start_phases
	.endl


	.local descriptor4
	s1 = 121
	s2 = 119
	s3 = 122
	s4 = 117
	.byte 20					;letter_count
	.byte $80					;letter_color
;	.byte  -  -  -  -  -  - -  -  -  -  -  -  -  -  -  -  - -  -  -  -  --  -  -  -  -  - -  -  -  -  -  -  -  -  -  - -  -  -  - 
	.byte  0, 2, 4, 6, 8,10,12,14,16,18,20,22,24,26,28,30,32,34,36,38	;start_offsets
;	.byte  1, 3, 5, 7, 9,11,13,15,17,19,21,23,25,27,29,31,33,35,37,39	;end_offsets
	.byte  2, 4, 6, 8,10,12,14,16,18,20,22,24,26,28,30,32,34,36,38,40	;end_offsets
	ins "intro/Silly-Intro-Loading.pic"	;picture
	.byte s1,s2,s3,s4,s1,s2,s3,s4,s1,s2,s3,s4,s1,s2,s3,s4,s1,s2,s3,s4	;start_phases
	.endl

;	.local descriptor4
;	s1 = 121
;	s2 = 119
;	s3 = 122
;	s4 = 117
;	.byte 40					;letter_count
;;	.byte  -  -  -  -  -  - -  -  -  -  -  -  -  -  -  -  - -  -  -  -  --  -  -  -  -  - -  -  -  -  -  -  -  -  -  - -  -  -  - 
;	.byte  0, 1, 2, 3, 4, 5, 6, 7, 8, 9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39	;start_offsets
;	.byte  1, 2, 3, 4, 5, 6, 7, 8, 9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40	;end_offsets
;	ins "intro/Silly-Intro-Loading.pic"	;picture
;	.byte s1,s2,s3,s4,s1,s2,s3,s4,s1,s2,s3,s4,s1,s2,s3,s4,s1,s2,s3,s4,s1,s2,s3,s4,s1,s2,s3,s4,s1,s2,s3,s4,s1,s2,s3,s4,s1,s2,s3,s4	;start_phases
;	.endl

;===============================================================

	.proc clear
	clear_memory [>letter_sm*256] $2000
	rts
	.endp

;===============================================================

	.proc print
	jmp $ffff
generated_prints_adr = *-2
	.endp

;===============================================================


	.proc move_letters

loop	jsr move
	lda letter_offset
	lsr
	clc
	adc #$40
sync	cmp vcount
	bne sync

	.if .def debug_mode
	lda #4
	sta colbk
	.endif

	jsr print

	.if .def debug_mode
	lda #0
	sta colbk
	.endif

	ldx letter_count
	lda letter_phase-1,x
	bne loop
	rts

;===============================================================

	.proc move		; Print and animate the letters

	ldx letter_index
	cpx letter_count
	bcs all_letters_done

	ldx #0

loop	lda letter_phase,x
	beq one_letter_done
	cmp #phase_not_started
	beq start_letter
	cmp #phase_completed	;End status
	beq next_letter
	jmp letter_already_started

start_letter
	cpx #0
	beq first_letter
	lda letter_phase-1,x
	cmp #phase_completed
	beq first_letter
	cmp $ffff,x
start_phases_adr = *-2
	bcs next_letter
first_letter
	lda #phase_start
	sta letter_phase,x
	bne next_letter

letter_already_started
	dec letter_phase,x
	bne same_letter
	inc letter_index

same_letter
next_letter
	inx
	cpx letter_count
	bne loop

all_letters_done
	rts

one_letter_done
	lda #$fe			;End status
	sta letter_phase,x
	bne next_letter

	.endp	;End of move

	.endp

;===============================================================
	.proc fade_out
	
	.var letter .byte

	ldx #0
	lda #32
init_loop
	sta letter_phase,x
	clc
	adc #6
	inx
	cpx letter_count
	bne init_loop

bright_loop
	jsr sync.vcount

	mva #0 letter
letter_loop
	ldx letter
	lda letter_phase,x
	beq letter_done
	sec
	sbc #1
	sta letter_phase,x
	cmp #32
	bcs letter_done
	lsr
	tay
	lda letter_fade_color,y
	sta letter_color1

	lda letter_adrlo,x
	sta jsr_adr
	lda letter_adrhi,x
	sta jsr_adr+1

	lda letter_color1
	asl
	asl
	asl
	asl
	sta letter_color2
	ora letter_color1
	tax
	ldy letter_wave1+16
	jsr $ffff
jsr_adr = *-2

letter_done
	inc letter
	lda letter
	cmp letter_count
	bne letter_loop
	ldx letter_count
	lda letter_phase-1,x
	bne bright_loop
	rts

	.endp

;===============================================================

	.proc vbi
	jsr sound.play
	inc cnt
	jmp xitvbv
	.endp	;End of vbi

	.endp	;End of effect

	.endp	;End of init

;===============================================================

	org sound_start

	.local sound

;	icl "intro/Silly-Intro-CMC-Player.asm"	; Does not work....

	ins "intro/Silly-Intro-CMC-Player-$5000.bin"
player		= $5000
player.init	= $5003
player.play	= $5006
player.posptr	= $500c
player.possng	= $500d
player.master_volume_reduction	.byte 0

;==========================================================

	.proc init		;Initializes the first song
	lda #>sound_d200	;Patch CMC replayer to store sound data at "sound_d200"
	sta player+$614

	ldx #<music
	ldy #>music
	lda #$70		;Init code
	jsr player.init
	lda #$00		;Set song code
	tax			;First song
	jmp player.init
	.endp

;==========================================================

	.proc play		 ;Plays sound per frame including volume control

	jsr player.play
	
	ldy #7
loop	lda sound_d200,y
	and #$f0
	sta mix
	lda sound_d200,y
	and #15
	sec
	sbc player.master_volume_reduction
	bcs positive
	lda #0
positive
	ora #0
mix	= *-1
	sta audf1,y
	dey
	dey
	bpl loop
	rts
	.endp

;==========================================================


	org music_start
music
;music	cmc_relocator 'C:\jac\system\Atari800\Programming\SND\snd\Nils-505-Checkpoint\Magical.cmc'
	ins "intro/Silly-Intro-Magical.cmc",+6

	.endl	;End of sound

;================================================================